IndexError at /

## Traceback Switch to copy-and-paste view

- `/home/foobaruser/.pyenv/versions/testsca/lib/python3.12/site-packages/django/core/handlers/exception.py`, line 55, in inner

  49.             return inner

  50.         else:

  52.             @wraps(get_response)

  53.             def inner(request):

  54.                 try:

  55.                     response = get_response(request)
                                         ^^^^^^^^^^^^^^^^^^^^^

      …

  56.                 except Exception as exc:

  57.                     response = response_for_exception(request, exc)

  58.                 return response

  60.             return inner

  Local vars

  Variable | Value
  --- | ---
  exc |
      IndexError()
  get_response |
      <bound method BaseHandler._get_response of <django.core.handlers.wsgi.WSGIHandler object at 0x739fa54fbf20>>
  request |
      <WSGIRequest: GET '/'>

- `/home/foobaruser/.pyenv/versions/testsca/lib/python3.12/site-packages/django/core/handlers/base.py`, line 197, in _get_response

  191.             if response is None:

  192.                 wrapped_callback = self.make_view_atomic(callback)

  193.                 # If it is an asynchronous view, run it in a subthread.

  194.                 if iscoroutinefunction(wrapped_callback):

  195.                     wrapped_callback = async_to_sync(wrapped_callback)

  196.                 try:

  197.                     response = wrapped_callback(request, *callback_args, **callback_kwargs)
                                           ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

       …

  198.                 except Exception as e:

  199.                     response = self.process_exception_by_middleware(e, request)

  200.                     if response is None:

  201.                         raise

  203.             # Complain if the view returned None (a common error).

  Local vars

  Variable | Value
  --- | ---
  callback |
      <function index_view at 0x739fa76b4d60>
  callback_args |
      ()
  callback_kwargs |
      {}
  request |
      <WSGIRequest: GET '/'>
  response |
      None
  self |
      <django.core.handlers.wsgi.WSGIHandler object at 0x739fa54fbf20>
  wrapped_callback |
      <function index_view at 0x739fa76b4d60>

- `/home/foobaruser/sources/minimal-django-example/app.py`, line 20, in index_view

  13.                 "DIRS": ["templates"],

  14.             },

  15.         ],

  16.     )

  19.     def index_view(request):

  20.         raise IndexError()
                  ^^^^^^^^^^^^^^^^^^

      …

  21.         return HttpResponse("<h1>Hello World From Django!</h1>")

  24.     def hello_view(request, name):

  25.         return render(request, "template.html", {"name": name})

  Local vars

  Variable | Value
  --- | ---
  request |
      <WSGIRequest: GET '/'>

Environment: Request Method: GET Request URL: http://localhost:8000/ Django Version: 5.1.5 Python Version: 3.12.5 Installed Applications: [] Installed Middleware: [] Traceback (most recent call last): File "/home/foobaruser/.pyenv/versions/testsca/lib/python3.12/site-packages/django/core/handlers/exception.py", line 55, in inner response = get_response(request) ^^^^^^^^^^^^^^^^^^^^^ File "/home/foobaruser/.pyenv/versions/testsca/lib/python3.12/site-packages/django/core/handlers/base.py", line 197, in _get_response response = wrapped_callback(request, *callback_args, **callback_kwargs) ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ File "/home/foobaruser/sources/minimal-django-example/app.py", line 20, in index_view raise IndexError() ^^^^^^^^^^^^^^^^^^ Exception Type: IndexError at / Exception Value:

## Request information

### USER

[unable to retrieve the current user]

### GET

No GET data

### POST

No POST data

### FILES

No FILES data

### COOKIES

Variable | Value
--- | ---
csrftoken |
    '********************'

### META

Variable | Value
--- | ---
AWS_ASSUME_ROLE_TTL |
    '1h'
AWS_SESSION_TTL |
    '24h'
AWS_VAULT_BACKEND |
    'secret-service'
AWS_VAULT_KEYCHAIN_NAME |
    '********************'
COLORTERM |
    'truecolor'
CONTENT_LENGTH |
    ''
CONTENT_TYPE |
    'text/plain'
DBUS_SESSION_BUS_ADDRESS |
    'unix:path=/run/user/1000/bus,guid=c3ac961ccc4c263877782e00678e0c9e'
DBUS_STARTER_ADDRESS |
    'unix:path=/run/user/1000/bus,guid=c3ac961ccc4c263877782e00678e0c9e'
DBUS_STARTER_BUS_TYPE |
    'session'
DESKTOP_SESSION |
    'ubuntu'
DISPLAY |
    ':0'
EDITOR |
    'vim'
EMAIL |
    'Juanjo Alvarez <juanjo@juanjoalvarez.net>'
GATEWAY_INTERFACE |
    'CGI/1.1'
GDMSESSION |
    'ubuntu'
GITLAB_TOKEN |
    '********************'
GNOME_DESKTOP_SESSION_ID |
    'this-is-deprecated'
GNOME_SETUP_DISPLAY |
    ':1'
GNOME_SHELL_SESSION_MODE |
    'ubuntu'
GOROOT |
    '/home/foobaruser/go'
GTK_MODULES |
    'gail:atk-bridge'
HDIV_PHP_EXTENSION_PATH |
    '/home/foobaruser/php/hdiv-php-extension/'
HOME |
    '/home/foobaruser'
HTTP_ACCEPT |
    'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7'
HTTP_ACCEPT_ENCODING |
    'gzip, deflate, br, zstd'
HTTP_ACCEPT_LANGUAGE |
    'en-US,en;q=0.9'
HTTP_CACHE_CONTROL |
    'max-age=0'
HTTP_CONNECTION |
    'keep-alive'
HTTP_COOKIE |
    '********************'
HTTP_DNT |
    '1'
HTTP_HOST |
    'localhost:8000'
HTTP_SEC_CH_UA |
    '"Google Chrome";v="131", "Chromium";v="131", "Not_A Brand";v="24"'
HTTP_SEC_CH_UA_MOBILE |
    '?0'
HTTP_SEC_CH_UA_PLATFORM |
    '"Linux"'
HTTP_SEC_FETCH_DEST |
    'document'
HTTP_SEC_FETCH_MODE |
    'navigate'
HTTP_SEC_FETCH_SITE |
    'none'
HTTP_SEC_FETCH_USER |
    '?1'
HTTP_UPGRADE_INSECURE_REQUESTS |
    '1'
HTTP_USER_AGENT |
    ('Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) '
     'Chrome/131.0.0.0 Safari/537.36')
IM_CONFIG_CHECK_ENV |
    '1'
IM_CONFIG_PHASE |
    '1'
INVOCATION_ID |
    '161a1822b4c24d129b1f0e3ef745a30f'
JOURNAL_STREAM |
    '8:61973'
LANG |
    'en_US.UTF-8'
LC_ADDRESS |
    'es_ES.UTF-8'
LC_IDENTIFICATION |
    'es_ES.UTF-8'
LC_MEASUREMENT |
    'es_ES.UTF-8'
LC_MONETARY |
    'es_ES.UTF-8'
LC_NAME |
    'es_ES.UTF-8'
LC_NUMERIC |
    'es_ES.UTF-8'
LC_PAPER |
    'es_ES.UTF-8'
LC_TELEPHONE |
    'es_ES.UTF-8'
LC_TIME |
    'es_ES.UTF-8'
LOGNAME |
    'foobaruser'
LS_COLORS |
    ''
LS_OPTIONS |
    '-N --color=auto -h'
MANAGERPID |
    '4414'
MANPATH |
    ':/opt/puppetlabs/puppet/share/man'
OMF_CONFIG |
    '/home/foobaruser/.config/omf'
OMF_PATH |
    '/home/foobaruser/.local/share/omf'
PATH |
    '/home/foobaruser/.pyenv/versions/testsca/bin:/home/foobaruser/.pyenv/libexec:/home/foobaruser/.pyenv/plugins/python-build/bin:/home/foobaruser/.pyenv/plugins/pyenv-virtualenv/bin:/home/foobaruser/.pyenv/plugins/pyenv-update/bin:/home/foobaruser/.pyenv/plugins/pyenv-installer/bin:/home/foobaruser/.pyenv/plugins/pyenv-doctor/bin:/home/foobaruser/.pyenv/plugins/pyenv-virtualenv/shims:/home/foobaruser/.pyenv/shims:/home/foobaruser/.pyenv/bin:/home/foobaruser/pyenv/bin:/home/foobaruser/.local/bin:/home/foobaruser/sources/graalvm-ce-java11-20.1.0/bin:/home/foobaruser/.fzf/bin:/home/foobaruser/.cargo/bin:/home/foobaruser/.krew/bin:/home/foobaruser/.tfenv/bin:/home/foobaruser/dd/devtools/bin:/usr/local/bin:/home/foobaruser/.local/bin:/home/foobaruser/.krew/bin:/home/foobaruser/.pyenv/bin:/home/foobaruser/.tfenv/bin:/home/foobaruser/dd/devtools/bin:/usr/local/bin:/home/foobaruser/.yarn/bin:/home/foobaruser/.config/yarn/global/node_modules/.bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/games:/usr/local/games:/snap/bin:/snap/bin:/opt/puppetlabs/bin:/home/foobaruser/bin:/home/foobaruser/sync/work/d/dmd2:/home/foobaruser/sources/nim/bin:/home/foobaruser/.nimble/bin'
PATH_INFO |
    '/'
PWD |
    '/home/foobaruser/sources/minimal-django-example'
PYENV_DIR |
    '/home/foobaruser/sources/minimal-django-example'
PYENV_HOOK_PATH |
    '/home/foobaruser/.pyenv/pyenv.d:/usr/etc/pyenv.d:/usr/local/etc/pyenv.d:/etc/pyenv.d:/usr/lib/pyenv/hooks:/home/foobaruser/.pyenv/plugins/pyenv-virtualenv/etc/pyenv.d:/home/foobaruser/.pyenv/plugins/pyenv-which-ext/etc/pyenv.d'
PYENV_ROOT |
    '/home/foobaruser/.pyenv'
PYENV_SHELL |
    'fish'
PYENV_VERSION |
    'testsca'
PYENV_VIRTUALENV_INIT |
    '1'
PYENV_VIRTUAL_ENV |
    '/home/foobaruser/.pyenv/versions/3.12.5/envs/testsca'
QT_ACCESSIBILITY |
    '1'
QT_IM_MODULE |
    'ibus'
QUERY_STRING |
    ''
REMOTE_ADDR |
    '127.0.0.1'
REMOTE_HOST |
    ''
REQUEST_METHOD |
    'GET'
RSYNC_PASSWORD |
    '********************'
RUN_MAIN |
    'true'
SCRIPT_NAME |
    ''
SERVER_NAME |
    'localhost'
SERVER_PORT |
    '8000'
SERVER_PROTOCOL |
    'HTTP/1.1'
SERVER_SOFTWARE |
    'WSGIServer/0.2'
SESSION_MANAGER |
    'local/foobaruser-ThinkPad-P15v-Gen-2i:@/tmp/.ICE-unix/5619,unix/foobaruser-ThinkPad-P15v-Gen-2i:/tmp/.ICE-unix/5619'
SHELL |
    '/bin/bash'
SHLVL |
    '1'
SSH_AGENT_LAUNCHER |
    'gnome-keyring'
SSH_AUTH_SOCK |
    '/run/user/1000/keyring/ssh'
SYSTEMD_EXEC_PID |
    '5619'
TERM |
    'xterm-256color'
TILIX_ID |
    '62221076-149e-426c-bba3-cf14d3a9099a'
USER |
    'foobaruser'
USERNAME |
    'foobaruser'
VIRTUAL_ENV |
    '/home/foobaruser/.pyenv/versions/3.12.5/envs/testsca'
VTE_VERSION |
    '6800'
WAYLAND_DISPLAY |
    'wayland-0'
XAUTHORITY |
    '/run/user/1000/.mutter-Xwaylandauth.50H8Z2'
XDG_CONFIG_DIRS |
    '/etc/xdg/xdg-ubuntu:/etc/xdg'
XDG_CURRENT_DESKTOP |
    'ubuntu:GNOME'
XDG_DATA_DIRS |
    '/usr/share/ubuntu:/home/foobaruser/.local/share/flatpak/exports/share:/var/lib/flatpak/exports/share:/usr/local/share/:/usr/share/:/var/lib/snapd/desktop'
XDG_MENU_PREFIX |
    'gnome-'
XDG_RUNTIME_DIR |
    '/run/user/1000'
XDG_SESSION_CLASS |
    'user'
XDG_SESSION_DESKTOP |
    'ubuntu'
XDG_SESSION_TYPE |
    'wayland'
XMODIFIERS |
    '@im=ibus'
wsgi.errors |
    <_io.TextIOWrapper name='<stderr>' mode='w' encoding='utf-8'>
wsgi.file_wrapper |
    <class 'wsgiref.util.FileWrapper'>
wsgi.input |
    <django.core.handlers.wsgi.LimitedStream object at 0x739fa53ad4b0>
wsgi.multiprocess |
    False
wsgi.multithread |
    True
wsgi.run_once |
    False
wsgi.url_scheme |
    'http'
wsgi.version |
    (1, 0)

### Settings

#### Using settings module ``

Setting | Value
--- | ---
ABSOLUTE_URL_OVERRIDES |
    {}
ADMINS |
    []
ALLOWED_HOSTS |
    []
APPEND_SLASH |
    True
AUTHENTICATION_BACKENDS |
    ['django.contrib.auth.backends.ModelBackend']
AUTH_PASSWORD_VALIDATORS |
    '********************'
AUTH_USER_MODEL |
    'auth.User'
CACHES |
    {'default': {'BACKEND': 'django.core.cache.backends.locmem.LocMemCache'}}
CACHE_MIDDLEWARE_ALIAS |
    'default'
CACHE_MIDDLEWARE_KEY_PREFIX |
    '********************'
CACHE_MIDDLEWARE_SECONDS |
    600
CSRF_COOKIE_AGE |
    31449600
CSRF_COOKIE_DOMAIN |
    None
CSRF_COOKIE_HTTPONLY |
    False
CSRF_COOKIE_NAME |
    'csrftoken'
CSRF_COOKIE_PATH |
    '/'
CSRF_COOKIE_SAMESITE |
    'Lax'
CSRF_COOKIE_SECURE |
    False
CSRF_FAILURE_VIEW |
    'django.views.csrf.csrf_failure'
CSRF_HEADER_NAME |
    'HTTP_X_CSRFTOKEN'
CSRF_TRUSTED_ORIGINS |
    []
CSRF_USE_SESSIONS |
    False
DATABASES |
    {'default': {'ATOMIC_REQUESTS': False,
                 'AUTOCOMMIT': True,
                 'CONN_HEALTH_CHECKS': False,
                 'CONN_MAX_AGE': 0,
                 'ENGINE': 'django.db.backends.dummy',
                 'HOST': '',
                 'NAME': '',
                 'OPTIONS': {},
                 'PASSWORD': '********************',
                 'PORT': '',
                 'TEST': {'CHARSET': None,
                          'COLLATION': None,
                          'MIGRATE': True,
                          'MIRROR': None,
                          'NAME': None},
                 'TIME_ZONE': None,
                 'USER': ''}}
DATABASE_ROUTERS |
    []
DATA_UPLOAD_MAX_MEMORY_SIZE |
    2621440
DATA_UPLOAD_MAX_NUMBER_FIELDS |
    1000
DATA_UPLOAD_MAX_NUMBER_FILES |
    100
DATETIME_FORMAT |
    'N j, Y, P'
DATETIME_INPUT_FORMATS |
    ['%Y-%m-%d %H:%M:%S',
     '%Y-%m-%d %H:%M:%S.%f',
     '%Y-%m-%d %H:%M',
     '%m/%d/%Y %H:%M:%S',
     '%m/%d/%Y %H:%M:%S.%f',
     '%m/%d/%Y %H:%M',
     '%m/%d/%y %H:%M:%S',
     '%m/%d/%y %H:%M:%S.%f',
     '%m/%d/%y %H:%M']
DATE_FORMAT |
    'N j, Y'
DATE_INPUT_FORMATS |
    ['%Y-%m-%d',
     '%m/%d/%Y',
     '%m/%d/%y',
     '%b %d %Y',
     '%b %d, %Y',
     '%d %b %Y',
     '%d %b, %Y',
     '%B %d %Y',
     '%B %d, %Y',
     '%d %B %Y',
     '%d %B, %Y']
DEBUG |
    True
DEBUG_PROPAGATE_EXCEPTIONS |
    False
DECIMAL_SEPARATOR |
    '.'
DEFAULT_AUTO_FIELD |
    'django.db.models.AutoField'
DEFAULT_CHARSET |
    'utf-8'
DEFAULT_EXCEPTION_REPORTER |
    'django.views.debug.ExceptionReporter'
DEFAULT_EXCEPTION_REPORTER_FILTER |
    'django.views.debug.SafeExceptionReporterFilter'
DEFAULT_FROM_EMAIL |
    'webmaster@localhost'
DEFAULT_INDEX_TABLESPACE |
    ''
DEFAULT_TABLESPACE |
    ''
DISALLOWED_USER_AGENTS |
    []
EMAIL_BACKEND |
    'django.core.mail.backends.smtp.EmailBackend'
EMAIL_HOST |
    'localhost'
EMAIL_HOST_PASSWORD |
    '********************'
EMAIL_HOST_USER |
    ''
EMAIL_PORT |
    25
EMAIL_SSL_CERTFILE |
    None
EMAIL_SSL_KEYFILE |
    '********************'
EMAIL_SUBJECT_PREFIX |
    '[Django] '
EMAIL_TIMEOUT |
    None
EMAIL_USE_LOCALTIME |
    False
EMAIL_USE_SSL |
    False
EMAIL_USE_TLS |
    False
FILE_UPLOAD_DIRECTORY_PERMISSIONS |
    None
FILE_UPLOAD_HANDLERS |
    ['django.core.files.uploadhandler.MemoryFileUploadHandler',
     'django.core.files.uploadhandler.TemporaryFileUploadHandler']
FILE_UPLOAD_MAX_MEMORY_SIZE |
    2621440
FILE_UPLOAD_PERMISSIONS |
    420
FILE_UPLOAD_TEMP_DIR |
    None
FIRST_DAY_OF_WEEK |
    0
FIXTURE_DIRS |
    []
FORCE_SCRIPT_NAME |
    None
FORMAT_MODULE_PATH |
    None
FORMS_URLFIELD_ASSUME_HTTPS |
    False
FORM_RENDERER |
    'django.forms.renderers.DjangoTemplates'
IGNORABLE_404_URLS |
    []
INSTALLED_APPS |
    []
INTERNAL_IPS |
    []
LANGUAGES |
    [('af', 'Afrikaans'),
     ('ar', 'Arabic'),
     ('ar-dz', 'Algerian Arabic'),
     ('ast', 'Asturian'),
     ('az', 'Azerbaijani'),
     ('bg', 'Bulgarian'),
     ('be', 'Belarusian'),
     ('bn', 'Bengali'),
     ('br', 'Breton'),
     ('bs', 'Bosnian'),
     ('ca', 'Catalan'),
     ('ckb', 'Central Kurdish (Sorani)'),
     ('cs', 'Czech'),
     ('cy', 'Welsh'),
     ('da', 'Danish'),
     ('de', 'German'),
     ('dsb', 'Lower Sorbian'),
     ('el', 'Greek'),
     ('en', 'English'),
     ('en-au', 'Australian English'),
     ('en-gb', 'British English'),
     ('eo', 'Esperanto'),
     ('es', 'Spanish'),
     ('es-ar', 'Argentinian Spanish'),
     ('es-co', 'Colombian Spanish'),
     ('es-mx', 'Mexican Spanish'),
     ('es-ni', 'Nicaraguan Spanish'),
     ('es-ve', 'Venezuelan Spanish'),
     ('et', 'Estonian'),
     ('eu', 'Basque'),
     ('fa', 'Persian'),
     ('fi', 'Finnish'),
     ('fr', 'French'),
     ('fy', 'Frisian'),
     ('ga', 'Irish'),
     ('gd', 'Scottish Gaelic'),
     ('gl', 'Galician'),
     ('he', 'Hebrew'),
     ('hi', 'Hindi'),
     ('hr', 'Croatian'),
     ('hsb', 'Upper Sorbian'),
     ('hu', 'Hungarian'),
     ('hy', 'Armenian'),
     ('ia', 'Interlingua'),
     ('id', 'Indonesian'),
     ('ig', 'Igbo'),
     ('io', 'Ido'),
     ('is', 'Icelandic'),
     ('it', 'Italian'),
     ('ja', 'Japanese'),
     ('ka', 'Georgian'),
     ('kab', 'Kabyle'),
     ('kk', 'Kazakh'),
     ('km', 'Khmer'),
     ('kn', 'Kannada'),
     ('ko', 'Korean'),
     ('ky', 'Kyrgyz'),
     ('lb', 'Luxembourgish'),
     ('lt', 'Lithuanian'),
     ('lv', 'Latvian'),
     ('mk', 'Macedonian'),
     ('ml', 'Malayalam'),
     ('mn', 'Mongolian'),
     ('mr', 'Marathi'),
     ('ms', 'Malay'),
     ('my', 'Burmese'),
     ('nb', 'Norwegian Bokmål'),
     ('ne', 'Nepali'),
     ('nl', 'Dutch'),
     ('nn', 'Norwegian Nynorsk'),
     ('os', 'Ossetic'),
     ('pa', 'Punjabi'),
     ('pl', 'Polish'),
     ('pt', 'Portuguese'),
     ('pt-br', 'Brazilian Portuguese'),
     ('ro', 'Romanian'),
     ('ru', 'Russian'),
     ('sk', 'Slovak'),
     ('sl', 'Slovenian'),
     ('sq', 'Albanian'),
     ('sr', 'Serbian'),
     ('sr-latn', 'Serbian Latin'),
     ('sv', 'Swedish'),
     ('sw', 'Swahili'),
     ('ta', 'Tamil'),
     ('te', 'Telugu'),
     ('tg', 'Tajik'),
     ('th', 'Thai'),
     ('tk', 'Turkmen'),
     ('tr', 'Turkish'),
     ('tt', 'Tatar'),
     ('udm', 'Udmurt'),
     ('ug', 'Uyghur'),
     ('uk', 'Ukrainian'),
     ('ur', 'Urdu'),
     ('uz', 'Uzbek'),
     ('vi', 'Vietnamese'),
     ('zh-hans', 'Simplified Chinese'),
     ('zh-hant', 'Traditional Chinese')]
LANGUAGES_BIDI |
    ['he', 'ar', 'ar-dz', 'ckb', 'fa', 'ug', 'ur']
LANGUAGE_CODE |
    'en-us'
LANGUAGE_COOKIE_AGE |
    None
LANGUAGE_COOKIE_DOMAIN |
    None
LANGUAGE_COOKIE_HTTPONLY |
    False
LANGUAGE_COOKIE_NAME |
    'django_language'
LANGUAGE_COOKIE_PATH |
    '/'
LANGUAGE_COOKIE_SAMESITE |
    None
LANGUAGE_COOKIE_SECURE |
    False
LOCALE_PATHS |
    []
LOGGING |
    {}
LOGGING_CONFIG |
    'logging.config.dictConfig'
LOGIN_REDIRECT_URL |
    '/accounts/profile/'
LOGIN_URL |
    '/accounts/login/'
LOGOUT_REDIRECT_URL |
    None
MANAGERS |
    []
MEDIA_ROOT |
    ''
MEDIA_URL |
    '/'
MESSAGE_STORAGE |
    'django.contrib.messages.storage.fallback.FallbackStorage'
MIDDLEWARE |
    []
MIGRATION_MODULES |
    {}
MONTH_DAY_FORMAT |
    'F j'
NUMBER_GROUPING |
    0
PASSWORD_HASHERS |
    '********************'
PASSWORD_RESET_TIMEOUT |
    '********************'
PREPEND_WWW |
    False
ROOT_URLCONF |
    '__main__'
SECRET_KEY |
    '********************'
SECRET_KEY_FALLBACKS |
    '********************'
SECURE_CONTENT_TYPE_NOSNIFF |
    True
SECURE_CROSS_ORIGIN_OPENER_POLICY |
    'same-origin'
SECURE_HSTS_INCLUDE_SUBDOMAINS |
    False
SECURE_HSTS_PRELOAD |
    False
SECURE_HSTS_SECONDS |
    0
SECURE_PROXY_SSL_HEADER |
    None
SECURE_REDIRECT_EXEMPT |
    []
SECURE_REFERRER_POLICY |
    'same-origin'
SECURE_SSL_HOST |
    None
SECURE_SSL_REDIRECT |
    False
SERVER_EMAIL |
    'root@localhost'
SESSION_CACHE_ALIAS |
    'default'
SESSION_COOKIE_AGE |
    1209600
SESSION_COOKIE_DOMAIN |
    None
SESSION_COOKIE_HTTPONLY |
    True
SESSION_COOKIE_NAME |
    'sessionid'
SESSION_COOKIE_PATH |
    '/'
SESSION_COOKIE_SAMESITE |
    'Lax'
SESSION_COOKIE_SECURE |
    False
SESSION_ENGINE |
    'django.contrib.sessions.backends.db'
SESSION_EXPIRE_AT_BROWSER_CLOSE |
    False
SESSION_FILE_PATH |
    None
SESSION_SAVE_EVERY_REQUEST |
    False
SESSION_SERIALIZER |
    'django.contrib.sessions.serializers.JSONSerializer'
SHORT_DATETIME_FORMAT |
    'm/d/Y P'
SHORT_DATE_FORMAT |
    'm/d/Y'
SIGNING_BACKEND |
    'django.core.signing.TimestampSigner'
SILENCED_SYSTEM_CHECKS |
    []
STATICFILES_DIRS |
    []
STATICFILES_FINDERS |
    ['django.contrib.staticfiles.finders.FileSystemFinder',
     'django.contrib.staticfiles.finders.AppDirectoriesFinder']
STATIC_ROOT |
    None
STATIC_URL |
    None
STORAGES |
    {'default': {'BACKEND': 'django.core.files.storage.FileSystemStorage'},
     'staticfiles': {'BACKEND': 'django.contrib.staticfiles.storage.StaticFilesStorage'}}
TEMPLATES |
    [{'BACKEND': 'django.template.backends.django.DjangoTemplates',
      'DIRS': ['templates']}]
TEST_NON_SERIALIZED_APPS |
    []
TEST_RUNNER |
    'django.test.runner.DiscoverRunner'
THOUSAND_SEPARATOR |
    ','
TIME_FORMAT |
    'P'
TIME_INPUT_FORMATS |
    ['%H:%M:%S', '%H:%M:%S.%f', '%H:%M']
TIME_ZONE |
    'America/Chicago'
USE_I18N |
    True
USE_THOUSAND_SEPARATOR |
    False
USE_TZ |
    True
USE_X_FORWARDED_HOST |
    False
USE_X_FORWARDED_PORT |
    False
WSGI_APPLICATION |
    None
X_FRAME_OPTIONS |
    'DENY'
YEAR_MONTH_FORMAT |
    'F Y'